@@ -10,7 +10,7 @@ from . import design, profile
 #@config.Float_flag('tweak_bulgepos1')
 #@config.Float_flag('tweak_bulgepos2')
 @config.Float_flag('tweak_boreless')
-class Design_whistle(design.Instrument_designer):
+class Design_whistle(design.Instrument_designer_with_bore_scale):
     def get_whistle_maker(self):
         from . import make_whistle
         bore = self.inner_diameters[-1]
@@ -83,8 +83,8 @@ class Design_folk_whistle(Design_whistle):
     
     initial_length = design.wavelength('D4') * 0.5
     
-    min_hole_diameters = design.sqrt_scaler([ 3.0 ]*6)
-    max_hole_diameters = design.sqrt_scaler([ 13.0 ]*6)
+    min_hole_diameters = design.bore_scaler([ 3.0 ]*6)
+    max_hole_diameters = design.bore_scaler([ 13.0 ]*6)
     
     horiz_angles = [ 0.0 ] * 6
     mid_cut = 3
@@ -96,15 +96,15 @@ class Design_folk_whistle(Design_whistle):
         b = self.inner_diameters[-1]
         return [ b*1.15 ] * 5 #[ b,b,b*1.25,b,b ]
 
-    inner_diameters = design.sqrt_scaler([ 24.0, 20.0, 20.0, 22.0, 20.0, 20.0 ])
+    inner_diameters = design.bore_scaler([ 24.0, 20.0, 20.0, 22.0, 20.0, 20.0 ])
     initial_inner_fractions = [ 0.2, 0.6,0.65,0.7 ]
     min_inner_fraction_sep = [ 0.02 ] * 5
 
-#    outer_diameters = design.sqrt_scaler([ 38.0, 28.0, 28.0 ])    
+#    outer_diameters = design.bore_scaler([ 38.0, 28.0, 28.0 ])    
 #    initial_outer_fractions = [ 0.15 ]
 #    min_outer_fraction_sep = [ 0.15, 0.8 ]
 
-    outer_diameters = design.sqrt_scaler([ 40.0, 28.0, 28.0, 32.0, 32.0 ])    
+    outer_diameters = design.bore_scaler([ 40.0, 28.0, 28.0, 32.0, 32.0 ])    
     initial_outer_fractions = [ 0.15, 0.5, 0.85 ]
     min_outer_fraction_sep = [ 0.15, 0.3, 0.35, 0.15 ]
     
@@ -146,8 +146,8 @@ class Design_recorder(Design_whistle):
     
     initial_length = design.wavelength('C4') * 0.5
     
-    min_hole_diameters = design.sqrt_scaler([ 3.0 ]*8)
-    max_hole_diameters = design.sqrt_scaler([ 12.0 ] + [ 14.0 ]*7)
+    min_hole_diameters = design.bore_scaler([ 3.0 ]*8)
+    max_hole_diameters = design.bore_scaler([ 12.0 ] + [ 14.0 ]*7)
     min_hole_spacing = design.sqrt_scaler([ 0.0 ]*6+[-50.0])
 
     horiz_angles = [ -15.0 ] + [ 0.0 ] * 6 + [ 180.0 ]
@@ -160,12 +160,12 @@ class Design_recorder(Design_whistle):
     #    b = self.inner_diameters[-1]
     #    return [ b*1.15 ] * 5 #[ b,b,b*1.25,b,b ]
 
-#    inner_diameters = design.sqrt_scaler([ 17.0, 20.0, 20.0, 23.0, 20.0, 20.0 ])
-    inner_diameters = design.sqrt_scaler([ 20.0, 20.0, 19.0, 23.0, 23.0, 20.0, 20.0 ])
+#    inner_diameters = design.bore_scaler([ 17.0, 20.0, 20.0, 23.0, 20.0, 20.0 ])
+    inner_diameters = design.bore_scaler([ 20.0, 20.0, 19.0, 23.0, 23.0, 20.0, 20.0 ])
     initial_inner_fractions = [ 0.6,0.65,0.7,0.75,0.8 ]
     min_inner_fraction_sep = [ 0.3,0.01,0.01,0.01,0.01,0.01 ]
 
-    outer_diameters = design.sqrt_scaler([ 40.0, 28.0, 28.0, 32.0, 32.0 ])    
+    outer_diameters = design.bore_scaler([ 40.0, 28.0, 28.0, 32.0, 32.0 ])    
     initial_outer_fractions = [ 0.15, 0.6, 0.85 ]
     min_outer_fraction_sep = [ 0.15, 0.3, 0.35, 0.15 ]
 
@@ -225,17 +225,22 @@ class Design_recorder(Design_whistle):
 Design a three hole pipe, i.e. the pipe in pipe-and-tabor.
 """)
 class Design_three_hole_whistle(Design_whistle):
+    bore_scale = 1.25
+    
     divisions = [
+        [],
         [(2,0.3)],
         [(2,0.05),(2,0.5)],
         [(2,0),(2,0.333),(2,0.666)],
+        [(0,0),(2,0),(2,0.333),(2,0.666)],
         ]
     
     initial_length = design.wavelength('D3') * 0.5
     
-    min_hole_diameters = design.sqrt_scaler([ 3.0 ]*3)
-    max_hole_diameters = design.sqrt_scaler([ 14.0 ]*3)
+    min_hole_diameters = design.bore_scaler([ 3.0 ]*3)
+    max_hole_diameters = design.bore_scaler([ 14.0 ]*3)
     
+    hole_angles = [ 0.0, 0.0, 0.0 ]
     horiz_angles = [ 0.0, 0.0, 180.0 ]
     mid_cut = 2
     
@@ -243,15 +248,13 @@ class Design_three_hole_whistle(Design_whistle):
     
     initial_hole_fractions = [ 0.1,0.15,0.2 ]
     
-    inner_diameters = design.sqrt_scaler([ 15.0, 15.0, 20.0, 20.0 ])
+    inner_diameters = design.bore_scaler([ 15.0, 15.0, 20.0, 20.0 ])
     initial_inner_fractions = [ 0.1, 0.75 ]
     
-    outer_diameters = design.sqrt_scaler([ 40.0, 28.0, 28.0, 32.0, 32.0 ])
-    min_outer_fraction_sep = [ 0.1, 0.45, 0.3, 0.1 ]
-    initial_outer_fractions = [ 0.1, 0.6, 0.9 ]
-    
-    
-    
+    outer_diameters = design.bore_scaler([ 23.0, 28.0, 32.0, 32.0 ])
+    min_outer_fraction_sep = [ 0.55, 0.3, 0.1 ]
+    initial_outer_fractions = [ 0.6, 0.9 ]
+        
     min_inner_fraction_sep = [ 0.01 ] * 8
 
     fingerings = [
